package edujin;

import edujin.handler.LoggingHandler;
import edujin.service.ArticleService;
import edujin.service.ResetPasswordService;
import edujin.service.SubscriptionService;
import edujin.util.ConfigHandler;
import edujin.util.HibernateUtil;

import javax.xml.ws.Binding;
import javax.xml.ws.Endpoint;
import javax.xml.ws.handler.Handler;
import java.util.List;

public class Main {
    public static void main(String[] args) {
        System.out.println("Test");
        System.setProperty("javax.xml.bind.JAXBContext",
                "com.sun.xml.internal.bind.v2.ContextFactory");
        ConfigHandler configHandler = ConfigHandler.getInstance();
        String serverHost = configHandler.get("server.host");
        String serverPort = configHandler.get("server.port");
        String serverUrl = "http://" + serverHost + ":" + serverPort;

        HibernateUtil.getSessionFactory();
        try {
            Endpoint endpointSubscription = Endpoint.create(new SubscriptionService());
            Endpoint endpointReset = Endpoint.create(new ResetPasswordService());
            Endpoint endpointArticle = Endpoint.create(new ArticleService());

            Binding bindingSubscription = endpointReset.getBinding();
            Binding bindingReset = endpointSubscription.getBinding();
            Binding bindingArticle = endpointArticle.getBinding();

            List<Handler> handlerChainSubs = bindingSubscription.getHandlerChain();
            List<Handler> handlerChainRes = bindingReset.getHandlerChain();
            List<Handler> handlerChainArt = bindingArticle.getHandlerChain();

            handlerChainSubs.add(new LoggingHandler());
            handlerChainRes.add(new LoggingHandler());
            handlerChainArt.add(new LoggingHandler());

            bindingSubscription.setHandlerChain(handlerChainSubs);
            bindingReset.setHandlerChain(handlerChainRes);
            bindingArticle.setHandlerChain(handlerChainArt);

            endpointSubscription.publish(serverUrl + "/subscribe");
            endpointReset.publish(serverUrl + "/reset");
            endpointArticle.publish(serverUrl + "/article");
            System.out.println("Server started");
        } catch (Exception e) {
            System.out.println("Server failed: " + e);
        }
    }
}