package edujin.model;

import edujin.util.ConfigHandler;
import io.github.cdimascio.dotenv.Dotenv;
import lombok.Getter;
import lombok.Setter;

import javax.mail.*;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;
import java.io.UnsupportedEncodingException;
import java.util.Date;
import java.util.Properties;
@Getter @Setter
public class Email {
    private final String SMPTP_HOST = Dotenv.load().get("SMPTP_HOST");
    private final String SMPTP_PORT = Dotenv.load().get("SMPTP_PORT");
    private final String SMPTP_USERNAME = Dotenv.load().get("SMPTP_USERNAME");
    private final String SMPTP_PASSWORD = Dotenv.load().get("SMPTP_PASSWORD");
    private String toEmail;
    private String subjectEmail;
    private String fromEmail;
    private String bodyEmail;
    private String fromEmailName;
    public Email(String toEmail) {
        this.toEmail = toEmail;
        this.subjectEmail = "";
        this.bodyEmail = "";
        this.fromEmail = "edujin@edujin.com";
        this.fromEmailName = "Edujin";
    }

    public void sendEmail() throws UnsupportedEncodingException {

        // Set the email properties
        Properties props = new Properties();
        props.put("mail.smtp.host", SMPTP_HOST);	// SMTP Host
        props.put("mail.smtp.port", SMPTP_PORT); 	// SMTP Port
        props.put("mail.smtp.auth", "true"); 		// SMTP Authentication Enabled

        // Create an authenticator object
        Authenticator auth = new Authenticator() {
            protected PasswordAuthentication getPasswordAuthentication() {
                return new PasswordAuthentication(SMPTP_USERNAME, SMPTP_PASSWORD);
            }
        };

        Session session = Session.getInstance(props, auth);
        try
        {
            MimeMessage msg = new MimeMessage(session);

            msg.addHeader("Content-type", "text/HTML; charset=UTF-8");
            msg.addHeader("Content-Transfer-Encoding", "8bit");
            msg.setSentDate(new Date());

            msg.setFrom(new InternetAddress(fromEmail, fromEmailName));
            msg.setReplyTo(InternetAddress.parse(fromEmail, false));

            msg.setSubject(subjectEmail, "UTF-8");
            msg.setText(bodyEmail, "UTF-8");
            msg.setRecipients(Message.RecipientType.TO, InternetAddress.parse(toEmail, false));
            System.out.println("Message is ready");

            Transport.send(msg);
        }
        catch (MessagingException mex) {
            System.out.println("\n--Exception handling in msgsendsample.java");

            mex.printStackTrace();
            System.out.println();
            Exception ex = mex;
            do {
                if (ex instanceof SendFailedException) {
                    SendFailedException sfex = (SendFailedException)ex;
                    Address[] invalid = sfex.getInvalidAddresses();
                    if (invalid != null) {
                        System.out.println("    ** Invalid Addresses");
                        for (Address address : invalid) System.out.println("         " + address);
                    }
                    Address[] validUnsent = sfex.getValidUnsentAddresses();
                    if (validUnsent != null) {
                        System.out.println("    ** ValidUnsent Addresses");
                        for (Address address : validUnsent) System.out.println("         " + address);
                    }
                    Address[] validSent = sfex.getValidSentAddresses();
                    if (validSent != null) {
                        System.out.println("    ** ValidSent Addresses");
                        for (Address address : validSent) System.out.println("         " + address);
                    }
                }
                System.out.println();
                if (ex instanceof MessagingException)
                    ex = ((MessagingException)ex).getNextException();
                else
                    ex = null;
            } while (ex != null);
        } catch (UnsupportedEncodingException e) {
            throw e;
        }
    }
}
