package edujin.util;

import edujin.model.Article;
import edujin.model.Logging;
import edujin.model.Subscription;
import edujin.model.Token;
import org.hibernate.SessionFactory;
import org.hibernate.boot.registry.StandardServiceRegistryBuilder;
import org.hibernate.cfg.Configuration;
import org.hibernate.service.ServiceRegistry;

import java.util.Properties;

public class HibernateUtil {
    private static final String DB_URL_KEY = "db.url";
    private static final String DB_USER_KEY = "db.username";
    private static final String DB_PASS_KEY = "db.password";
    private static SessionFactory sessionFactory;
    private static Configuration getConfiguration() {
        ConfigHandler configHandler = ConfigHandler.getInstance();
        String dbUrl = configHandler.get(DB_URL_KEY);
        String dbUser = configHandler.get(DB_USER_KEY);
        String dbPass = configHandler.get(DB_PASS_KEY);

        Properties properties = new Properties();
        properties.setProperty("hibernate.dialect", "org.hibernate.dialect.MySQL8Dialect");
        properties.setProperty("hibernate.connection.driver_class", "com.mysql.jdbc.Driver");
        properties.setProperty("hibernate.connection.url", dbUrl);
        properties.setProperty("hibernate.connection.username", dbUser);
        properties.setProperty("hibernate.connection.password", dbPass);
        properties.setProperty("hibernate.hbm2ddl.auto", "update");
        properties.setProperty("hibernate.use_second_level_cache", "false");
        properties.put("hibernate.current_session_context_class", "thread");

        Configuration configuration = new Configuration();
        configuration.addAnnotatedClass(Token.class);
        configuration.addAnnotatedClass(Logging.class);
        configuration.addAnnotatedClass(Subscription.class);
        configuration.addAnnotatedClass(Article.class);
        configuration.setProperties(properties);
        return configuration;
    }

    private static SessionFactory buildSessionFactory() {
        Configuration configuration = getConfiguration();

        ServiceRegistry serviceRegistry = new StandardServiceRegistryBuilder()
                .applySettings(configuration.getProperties())
                .build();

        try {
            sessionFactory = configuration.buildSessionFactory(serviceRegistry);
        }
        catch (Exception e) {
            // The registry would be destroyed by the SessionFactory, but we had trouble building the SessionFactory
            // so destroy it manually.
            StandardServiceRegistryBuilder.destroy(serviceRegistry);
            throw e;
        }
        return sessionFactory;
    }

    public static SessionFactory getSessionFactory() {
        if (HibernateUtil.sessionFactory == null) {
            HibernateUtil.sessionFactory = HibernateUtil.buildSessionFactory();
        }
        return HibernateUtil.sessionFactory;
    }
}
